@@ -13,7 +13,7 @@ def respond(channel, callback, exchange=None, **kwargs):
 def on_request(callback, ch, method, props, message, exchange = None):
     if exchange is None:
         exchange = "DEFAULT_EXCHANGE"
-    response = callback(from_json(message).body)
+    response = callback(from_json(message))
 
     ch.basic_publish(exchange=exchange,
                      routing_key=props.reply_to,
